==> haskell-lexer-1.0.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lexer.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-lexer
version: 1.0.1
id: haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3
key: haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3
license: BSD-3-Clause
maintainer: diatchki@galois.com
author: Thomas Hallgren
synopsis: A fully compliant Haskell 98 lexer.
description:
    A fully compliant Haskell 98 lexer.
category: Language
abi: 031c68d5bbb9ae48cb447f84f1dce56a
exposed: True
exposed-modules:
    Language.Haskell.Lexer
hidden-modules: Language.Haskell.Lexer.Layout
                Language.Haskell.Lexer.Tokens Language.Haskell.Lexer.Lex
                Language.Haskell.Lexer.Utils Language.Haskell.Lexer.Position
import-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-lexer-1.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-lexer-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haskell-lexer-1.0.1
hs-libraries: HShaskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html: /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lexer-1.0.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lexer.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-lexer
version: 1.0.2
id: haskell-lexer-1.0.2-KO2GOhgi16nEU9sikYYrpY
key: haskell-lexer-1.0.2-KO2GOhgi16nEU9sikYYrpY
license: BSD-3-Clause
maintainer: diatchki@galois.com
author: Thomas Hallgren
homepage: https://github.com/yav/haskell-lexer
synopsis: A fully compliant Haskell 98 lexer.
description:
    A fully compliant Haskell 98 lexer.
category: Language
abi: 9511c2819e3d91bd96fe7fb45dc77164
exposed: True
exposed-modules:
    Language.Haskell.Lexer
hidden-modules: Language.Haskell.Lexer.Layout
                Language.Haskell.Lexer.Tokens Language.Haskell.Lexer.Lex
                Language.Haskell.Lexer.Utils Language.Haskell.Lexer.Position
import-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-lexer-1.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-lexer-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haskell-lexer-1.0.2
hs-libraries: HShaskell-lexer-1.0.2-KO2GOhgi16nEU9sikYYrpY
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html: /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
